import { useState, lazy, Suspense, useCallback, useEffect } from "react";
import { Menu, Calendar, ExternalLink } from "lucide-react";
import { Button } from "@/components/ui/button";
import { Sheet, SheetContent, SheetTrigger } from "@/components/ui/sheet";
import { Link, useLocation } from "wouter";

// Optimized navItems array with memoization
const navItems = [
  { label: "About", href: "/about", scroll: "about" },
  { label: "Experience", href: "/experience", scroll: "experience" },
  { label: "Skills", href: "/skills", scroll: "skills" },
  { label: "Blog", href: "/blog", scroll: "blog" },
  { label: "FAQ", href: "/faq", scroll: "faq" },
  { label: "Contact", href: "/contact", scroll: "contact" },
] as const;

// Lazy load the mobile navigation to improve initial load performance
const MobileNavigation = lazy(() => import("./mobile-navigation"));

export default function Navigation() {
  const [isOpen, setIsOpen] = useState(false);
  const [location] = useLocation();

  // Memoized active state check for performance
  const isActive = useCallback((path: string) => location === path, [location]);

  // Handle smooth scrolling for home page sections
  const handleNavClick = useCallback((path: string, scroll?: string) => {
    // Track navigation timing
    const navigationStart = performance.now();

    if (location === '/' && scroll) {
      const element = document.getElementById(scroll);
      if (element) {
        element.scrollIntoView({ behavior: 'smooth', block: 'start' });
        // Track scroll performance
        if (typeof window !== 'undefined' && 'gtag' in window) {
          (window as any).gtag('event', 'section_scroll', {
            section: scroll,
            timing: performance.now() - navigationStart
          });
        }
        return;
      }
    }

    // Track regular navigation
    if (typeof window !== 'undefined' && 'gtag' in window) {
      (window as any).gtag('event', 'navigation', {
        path,
        timing: performance.now() - navigationStart
      });
    }
  }, [location]);

  // Intersection Observer for active section highlighting
  useEffect(() => {
    if (location === '/') {
      const observer = new IntersectionObserver(
        (entries) => {
          entries.forEach((entry) => {
            if (entry.isIntersecting) {
              const id = entry.target.id;
              // Update active state in analytics
              if (typeof window !== 'undefined' && 'gtag' in window) {
                (window as any).gtag('event', 'section_view', { section: id });
              }
            }
          });
        },
        { threshold: 0.5 }
      );

      navItems.forEach(({ scroll }) => {
        const element = document.getElementById(scroll);
        if (element) observer.observe(element);
      });

      return () => observer.disconnect();
    }
  }, [location]);

  return (
    <nav className="fixed top-0 left-0 right-0 z-50 bg-background/80 backdrop-blur-sm border-b border-primary/20">
      <div className="container mx-auto px-4 h-16 flex items-center justify-between">
        <Link href="/">
          <a className="text-2xl font-bold bg-gradient-to-r from-primary to-primary/60 bg-clip-text text-transparent">
            MS
          </a>
        </Link>

        {/* Desktop Navigation - Performance optimized */}
        <div className="hidden md:flex items-center gap-8">
          {navItems.map((item) => (
            <Link
              key={item.href}
              href={item.href}
              onClick={() => handleNavClick(item.href, item.scroll)}
              className={`text-foreground/60 hover:text-primary transition-colors ${
                isActive(item.href) ? "text-primary" : ""
              }`}
            >
              {item.label}
            </Link>
          ))}
          <div className="flex items-center gap-4">
            <Button 
              asChild 
              className="bg-primary/20 hover:bg-primary/30 text-primary border border-primary/30"
              onClick={() => {
                if (typeof window !== 'undefined' && 'gtag' in window) {
                  (window as any).gtag('event', 'external_link_click', {
                    destination: 'y12.ai'
                  });
                }
              }}
            >
              <a 
                href="https://y12.ai" 
                target="_blank" 
                rel="noopener noreferrer"
                aria-label="Visit Y12.AI"
              >
                <ExternalLink className="w-4 h-4 mr-2" />
                <span>Y12.AI</span>
              </a>
            </Button>
            <Link href="/experience">
              <Button 
                className="bg-primary/20 hover:bg-primary/30 text-primary border border-primary/30"
                onClick={() => handleNavClick('/experience')}
              >
                Experience
              </Button>
            </Link>
          </div>
        </div>

        {/* Mobile Navigation - Lazy loaded for better performance */}
        <Suspense fallback={
          <Button variant="ghost" size="icon" aria-label="Loading menu">
            <Menu className="h-6 w-6" />
          </Button>
        }>
          <Sheet open={isOpen} onOpenChange={setIsOpen}>
            <SheetTrigger asChild className="md:hidden">
              <Button variant="ghost" size="icon" aria-label="Menu">
                <Menu className="h-6 w-6" />
              </Button>
            </SheetTrigger>
            <SheetContent>
              <MobileNavigation 
                navItems={navItems} 
                isActive={isActive}
                onNavClick={handleNavClick}
                onClose={() => setIsOpen(false)}
              />
            </SheetContent>
          </Sheet>
        </Suspense>
      </div>
    </nav>
  );
}